Crate ford_johnson

Crate ford_johnson 

Functions

sort
Sort a slice of usize based on an explicit comparator. Usually used to perform an indirect sort (i.e., to compute the indices that would sort the given items).